# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-10-15 14:07
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_catalog', '0070_auto_20171013_1411'),
    ]

    operations = [
        migrations.AddField(
            model_name='collection',
            name='badged',
            field=models.BooleanField(default=False, verbose_name='Badged'),
        ),
        migrations.AddField(
            model_name='collection',
            name='virtual',
            field=models.BooleanField(default=False, verbose_name='Virtual'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-10-16 09:24
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('pcart_catalog', '0071_auto_20171015_1707'),
    ]

    operations = [
        migrations.CreateModel(
            name='PriceAggregationProfile',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('title', models.CharField(max_length=255, unique=True, verbose_name='Title')),
                ('account_id', models.CharField(help_text='The account ID on the particular price aggregator.', max_length=150, verbose_name='Account ID')),
                ('language', models.CharField(max_length=10, verbose_name='Language')),
                ('file_name', models.CharField(help_text='File name, like prices.xml for example.', max_length=150, unique=True, verbose_name='File name')),
                ('template_name', models.CharField(blank=True, default='', max_length=100, verbose_name='Template name')),
                ('added', models.DateTimeField(auto_now_add=True, verbose_name='Added')),
                ('changed', models.DateTimeField(auto_now=True, verbose_name='Changed')),
                ('site', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='price_aggregation_profiles', to='sites.Site', verbose_name='Site')),
            ],
            options={
                'ordering': ['title'],
                'verbose_name': 'Price aggregation profile',
                'verbose_name_plural': 'Price aggregation profiles',
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-10-16 09:29
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_catalog', '0072_priceaggregationprofile'),
    ]

    operations = [
        migrations.AlterField(
            model_name='priceaggregationprofile',
            name='account_id',
            field=models.CharField(blank=True, help_text='The account ID on the particular price aggregator.', max_length=150, verbose_name='Account ID'),
        ),
    ]
